#!/bin/bash

# Copyright (c) 2011-2012 Cloudera, Inc. All rights reserved.

# Time marker for both stderr and stdout
date; date 1>&2

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# attempt to find java
locate_java_home

# Load the parcel environment
source_parcel_environment

echo "using $JAVA_HOME as JAVA_HOME"
echo "using $CDH_VERSION as CDH_VERSION"
echo "using $HBASE_HOME as HBASE_HOME"
echo "using $CONF_DIR as HBASE_CONF_DIR"
echo "using $CONF_DIR as HADOOP_CONF_DIR"
echo "using $HADOOP_HOME as HADOOP_HOME"

set_hbase_classpath

export HADOOP_HOME=$CDH_HADOOP_HOME
export HBASE_HOME=$CDH_HBASE_HOME

# debug
set -x

# we set HADOOP_CONF_DIR explicitly to our CONF_DIR since otherwise the hbase
# script will use the default system hadoop configuration.
export HADOOP_CONF_DIR=$CONF_DIR

# local replacement of substitution variables.
# i.e. master doesn't know final resting place of configuration files
#   which may require absolute path (e.g. dfs_allows)
perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/*.xml

if [ -e $CONF_DIR/log4j.properties ]; then
  perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/log4j.properties
fi

acquire_kerberos_tgt hbase.keytab

# Disable IPv6.
export HBASE_OPTS="-Djava.net.preferIPv4Stack=true $HBASE_OPTS"

if [ "$HDFS_SHORT_CIRCUIT_READS_ENABLED" != "" ]; then
  # Bumping up the ulimit to a "large" number that is a power of 2
  ulimit -n 32768
  # Don't pollute the environment of the child
  HDFS_SHORT_CIRCUIT_READS_ENABLED=""
fi

if [ "region_mover" = "$1" ]; then
  REGION_MOVER_SCRIPT="${cloudera_config}/../hbase/region_mover.cdh$CDH_VERSION.rb"
  echo "Using $REGION_MOVER_SCRIPT as REGION_MOVER_SCRIPT"
  if [ ! -e $REGION_MOVER_SCRIPT ]; then
    echo "Error: $REGION_MOVER_SCRIPT not found"
    exit 1
  fi
  EXCLUDE_ARG=""
  if [ "unload" = "$2" ]; then
    EXCLUDE_ARG="-x $CONF_DIR/excludes.txt"
  elif [ "load" != "$2" ]; then
    echo "Error: Unknown argument $2. Must be either load or unload"
    exit 1
  fi
  # $2 = 'load' for reload and 'unload' for decommission
  # $3 is hostname to reload/decommission.
  exec $HBASE_HOME/bin/hbase --config $CONF_DIR org.jruby.Main $REGION_MOVER_SCRIPT $EXCLUDE_ARG $2 $3
elif [ "toggle_balancer" = "$1" ]; then
  # $2 tells whether to turn balancer on.
  SHELL_CMD="balance_switch $2"
  exec $HBASE_HOME/bin/hbase --config $CONF_DIR shell <<< $SHELL_CMD
else
  # check if a jaas config file is provided for zookeeper authentication
  if [ "$JAAS_FILE" != "" ]; then
    echo "using $JAAS_FILE as JAAS_FILE"
    export HBASE_MANAGES_ZK=false
    if [ "master" = "$1" ]; then
      export HBASE_MASTER_OPTS="-Djava.security.auth.login.config=$CONF_DIR/$JAAS_FILE $HBASE_MASTER_OPTS"
    elif [ "regionserver" = "$1" ]; then
      export HBASE_REGIONSERVER_OPTS="-Djava.security.auth.login.config=$CONF_DIR/$JAAS_FILE $HBASE_REGIONSERVER_OPTS"
    elif [ "rest" = "$1" ]; then
      export HBASE_REST_OPTS="-Djava.security.auth.login.config=$CONF_DIR/$JAAS_FILE $HBASE_REST_OPTS"
    fi
    elif [ "thrift" = "$1" ]; then
      export HBASE_THRIFT_OPTS="-Djava.security.auth.login.config=$CONF_DIR/$JAAS_FILE $HBASE_THRIFT_OPTS"
    fi
  fi	
  exec $HBASE_HOME/bin/hbase --config $CONF_DIR "$@"
fi
